==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebColumnVisibilityChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata } from "./WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata";
import { WebColumnVisibilityChangedEventArgsDescription } from "./WebColumnVisibilityChangedEventArgsDescription";
/**
 * @hidden
 */
export let WebColumnVisibilityChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebColumnVisibilityChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebColumnVisibilityChangedEventArgsDescriptionMetadata.a == null) {
                WebColumnVisibilityChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebColumnVisibilityChangedEventArgsDescriptionMetadata.c(WebColumnVisibilityChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebColumnVisibilityChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebColumnVisibilityChangedEventArgsDescriptionMetadata.a);
            WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ColumnVisibilityChangedEventArgs");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebColumnVisibilityChangedEventArgsDetail");
        }
        static d(a) {
            WebColumnVisibilityChangedEventArgsDescriptionMetadata.b(a);
            a.ad("WebColumnVisibilityChangedEventArgs", () => new WebColumnVisibilityChangedEventArgsDescription());
            a.ac("WebColumnVisibilityChangedEventArgs", WebColumnVisibilityChangedEventArgsDescriptionMetadata.a);
        }
    }
    WebColumnVisibilityChangedEventArgsDescriptionMetadata.$t = markType(WebColumnVisibilityChangedEventArgsDescriptionMetadata, 'WebColumnVisibilityChangedEventArgsDescriptionMetadata');
    WebColumnVisibilityChangedEventArgsDescriptionMetadata.a = null;
    return WebColumnVisibilityChangedEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebColumnVisibilityChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata } from "./WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata";
import { WebColumnVisibilityChangedEventArgsDescription } from "./WebColumnVisibilityChangedEventArgsDescription";
/**
 * @hidden
 */
export let WebColumnVisibilityChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebColumnVisibilityChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebColumnVisibilityChangedEventArgsDescriptionMetadata.a == null) {
                WebColumnVisibilityChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebColumnVisibilityChangedEventArgsDescriptionMetadata.c(WebColumnVisibilityChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebColumnVisibilityChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebColumnVisibilityChangedEventArgsDescriptionMetadata.a);
            WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ColumnVisibilityChangedEventArgs");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebColumnVisibilityChangedEventArgsDetail");
        }
        static d(a) {
            WebColumnVisibilityChangedEventArgsDescriptionMetadata.b(a);
            a.ae("WebColumnVisibilityChangedEventArgs", () => new WebColumnVisibilityChangedEventArgsDescription());
            a.ad("WebColumnVisibilityChangedEventArgs", WebColumnVisibilityChangedEventArgsDescriptionMetadata.a);
        }
    }
    WebColumnVisibilityChangedEventArgsDescriptionMetadata.$t = markType(WebColumnVisibilityChangedEventArgsDescriptionMetadata, 'WebColumnVisibilityChangedEventArgsDescriptionMetadata');
    WebColumnVisibilityChangedEventArgsDescriptionMetadata.a = null;
    return WebColumnVisibilityChangedEventArgsDescriptionMetadata;
})();
